@@ -15,16 +15,17 @@ def results_vis(f_dict: Dict[str,Forecaster],plot_type: str='forecast', print_at
     """ visualize the forecast results from many different Forecaster objects leveraging Jupyter widgets.
 
     Args:
-        f_dict (dict): dictionary of forcaster objects.
-        plot_type (str): one of {"forecast","test"}, default "forecast";
+        f_dict (dict[str,Forecaster]): dictionary of forcaster objects.
+            works best if two or more models have been evaluated in each dictionary value.
+        plot_type (str): one of {"forecast","test"}, default "forecast".
             the type of results to visualize.
-        print_attr (list): optional;
-            the attributes from history to print;
-            passed to print_attr parameter when plot_type = 'forecast';
+        print_attr (list): optional.
+            the attributes from history to print.
+            passed to print_attr parameter when plot_type = 'forecast'.
             ignored when plot_type = 'test'.
-        include_train (bool or int): optional;
-            whether to include the complete training set in the plot or how many traning-set observations to include;
-            passed to include_train parameter when plot_type = 'test';
+        include_train (bool or int): optional.
+            whether to include the complete training set in the plot or how many traning-set observations to include.
+            passed to include_train parameter when plot_type = 'test'.
             ignored when plot_type = 'forecast'.
 
     Returns:
@@ -51,7 +52,7 @@ def results_vis(f_dict: Dict[str,Forecaster],plot_type: str='forecast', print_at
         me_selection = me_dd.value
         with output:
             clear_output()
-            display_user_selections(ts_selection,mo_selection,lv_selection,me_selection)
+            display_user_selections(ts_selection,mo_selection,lv_selection,ci_selection,me_selection)
     
     all_models = []
     for k,f in f_dict.items():
@@ -67,7 +68,7 @@ def results_vis(f_dict: Dict[str,Forecaster],plot_type: str='forecast', print_at
     button = widgets.Button(description="Select Time Series")
     output = widgets.Output()
 
-    display(ts_dd,mo_dd,lv_dd,me_dd)
+    display(ts_dd,mo_dd,lv_dd,ci_dd,me_dd)
     display(button, output)
     
     button.on_click(on_button_clicked)
@@ -76,20 +77,20 @@ def tune_test_forecast(forecaster,models,dynamic_tuning=False,dynamic_testing=Tr
     """ tunes, tests, and forecasts a series of models with a progress bar through tqdm.
 
     Args:
-        forecaster (Forecaster): the object to visualize; works best if two or more models have been evaluated.
+        forecaster (Forecaster): the object to visualize.
         models (list-like):
-            each element must match an element in scalecast.Forecaster._estimators_ (except "combo", which cannot be tuned).
-        dynamic_tuning (bool): default False;
-            whether to dynamically tune the forecast (meaning AR terms will be propogated with predicted values);
-            setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods;
+            each element must be in _can_be_tuned_.
+        dynamic_tuning (bool): default False.
+            whether to dynamically tune the forecast (meaning AR terms will be propogated with predicted values).
+            setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
             when False, metrics effectively become an average of one-step forecasts.
-        dynamic_testing (bool): default True;
-            whether to dynamically test the forecast (meaning AR terms will be propogated with predicted values);
-            setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods;
+        dynamic_testing (bool): default True.
+            whether to dynamically test the forecast (meaning AR terms will be propogated with predicted values).
+            setting this to False means faster performance, but gives a less-good indication of how well the forecast will perform out x amount of periods.
             when False, test-set metrics effectively become an average of one-step forecasts.
-        summary_stats (bool): default False;
+        summary_stats (bool): default False.
             whether to save summary stats for the models that offer those.
-        feature_importance (bool): default False;
+        feature_importance (bool): default False.
             whether to save permutation feature importance information for the models that offer those.
 
     Returns:
